FileSource

Struct FileSource 

pub struct FileSource<T> { /* private fields */ }
Represents a source that reads configuration data from a file.

This struct is generic over T which is the parser type used to parse the file contents, and U which is the type of the path (defaults to PathBuf).

Type Parameters

  • T: The parser type that implements the Parser trait for parsing file contents.
  • U: The path type that implements AsRef<Path>, defaults to PathBuf.

Implementations

Source

impl<T> FileSource<T>

pub fn new<P: Into<PathBuf>>(path: P) -> Self

Constructs a new FileSource with the specified file path.

Arguments
  • path - A path to the file that will be read.