pub struct FileSource<T> { /* private fields */ }Expand description
Represents a source that reads configuration data from a file.
This struct is generic over T which is the parser type used to parse the
file contents, and U which is the type of the path (defaults to
PathBuf).
Type Parameters
T: The parser type that implements theParsertrait for parsing file contents.U: The path type that implementsAsRef<Path>, defaults toPathBuf.
Implementations